Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/static/bootstrap-tabs.js
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/static/bootstrap-tabs.js	(revision 7443)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/static/bootstrap-tabs.js	(revision 7443)
@@ -0,0 +1,80 @@
+/* ========================================================
+ * bootstrap-tabs.js v1.4.0
+ * http://twitter.github.com/bootstrap/javascript.html#tabs
+ * ========================================================
+ * Copyright 2011 Twitter, Inc.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ * ======================================================== */
+
+
+!function( $ ){
+
+  "use strict"
+
+  function activate ( element, container ) {
+    container
+      .find('> .active')
+      .removeClass('active')
+      .find('> .dropdown-menu > .active')
+      .removeClass('active')
+
+    element.addClass('active')
+
+    if ( element.parent('.dropdown-menu') ) {
+      element.closest('li.dropdown').addClass('active')
+    }
+  }
+
+  function tab( e ) {
+    var $this = $(this)
+      , $ul = $this.closest('ul:not(.dropdown-menu)')
+      , href = $this.attr('href')
+      , previous
+      , $href
+
+    if ( /^#\w+/.test(href) ) {
+      e.preventDefault()
+
+      if ( $this.parent('li').hasClass('active') ) {
+        return
+      }
+
+      previous = $ul.find('.active a').last()[0]
+      $href = $(href)
+
+      activate($this.parent('li'), $ul)
+      activate($href, $href.parent())
+
+      $this.trigger({
+        type: 'change'
+      , relatedTarget: previous
+      })
+    }
+  }
+
+
+ /* TABS/PILLS PLUGIN DEFINITION
+  * ============================ */
+
+  $.fn.tabs = $.fn.pills = function ( selector ) {
+    return this.each(function () {
+      $(this).delegate(selector || '.tabs li > a, .pills > li > a', 'click', tab)
+    })
+  }
+
+  $(document).ready(function () {
+    $('body').tabs('ul[data-tabs] li > a, ul[data-pills] > li > a')
+  })
+
+}( window.jQuery || window.ender );
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/static/waeup-base.css
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/static/waeup-base.css	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/static/waeup-base.css	(revision 7443)
@@ -4,2 +4,36 @@
 'waeuptheme-<SOME-NAME>.css' and include a utility and a resource in theming.py 
 and resources.py respectively. */
+
+body {
+  padding-top: 60px;
+}
+
+h2 {
+  margin-bottom: 12px;
+}
+
+label {
+  padding-top: 0px;
+}
+
+.breadcrumb {
+  margin-left: 20px;
+  margin-right: 20px;
+  min-width: 940px;
+}
+
+.form-table td {
+  padding: 5px 5px 4px;
+  border-top: none;
+}
+
+.error {
+  color: red;
+}
+
+
+ /* dataTables stuff */
+
+.dataTables_wrapper {
+  min-height: 150px;
+}
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatecoursepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatecoursepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatecoursepage.pt	(revision 7443)
@@ -1,5 +1,5 @@
 <h2 tal:content="context/longtitle">TITLE</h2>
 
-<table class="zebra">
+<table class="form-table">
   <thead>
   </thead>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatemanagepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatemanagepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatemanagepage.pt	(revision 7443)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,153 +13,153 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data"> 
 
-<div id="tabs">
-  <ul>
-    <li><a href="#tab-1"><span>Settings</span></a></li>
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active"><a href="#tab-1"><span>Settings</span></a></li>
     <li><a href="#tab-2"><span>Course Referrers</span></a></li>
     <li><a href="#tab-3"><span>Local Roles</span></a></li>
   </ul>
    
-  <div id="tab-1">
-        <table class="zebra">
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+          <table class="form-table">
+          <tbody>
+          <tal:block repeat="widget view/widgets">
+            <tr>
+              <td>
+                <label tal:attributes="for widget/name">
+                  <span tal:condition="widget/required">*</span>
+                  <span i18n:translate="" tal:content="widget/label">label</span>:
+                </label>
+              </td>
+              <td>
+                <span tal:content="structure widget">
+                  <input type="text" />
+                </span>
+                <tal:error tal:condition="widget/error">
+                  <span tal:replace="structure widget/error">error</span>
+                </tal:error>
+                <tal:hint tal:condition="widget/hint">
+                  <span tal:content="structure widget/hint">hint</span>
+                </tal:hint>
+              </td>
+            </tr>
+          </tal:block>
+          </tbody>
+          </table>
+          <div tal:condition="view/availableActions">
+            <span tal:repeat="action view/actions"
+                  tal:omit-tag="">
+              <input tal:condition="python:action.label in view.taboneactions"
+                     tal:replace="structure action/render"/>
+            </span>
+          </div>
+    </div>
+    <div id="tab-2">
+      <h3>Course Referrers</h3>
+      <table class="display dataTableManage">
+        <thead>
+          <tr>
+            <th>&nbsp;</th><th>Level</th><th>Semester</th><th>Referrer</th><th>Course</th><th>Title</th>
+            <th>Mandatory</th>
+          </tr>
+        </thead>
         <tbody>
-        <tal:block repeat="widget view/widgets">
-          <tr>
-            <td class="label">
-              <label tal:attributes="for widget/name">
-                <span class="required" tal:condition="widget/required">*</span>
-                <span i18n:translate="" tal:content="widget/label">label</span>:
-              </label>
+          <tr tal:repeat="cc context/values">
+             <td>
+              <input type="checkbox"
+        		 name="val_id"
+        		 tal:attributes="value cc/__name__" />
             </td>
-            <td class="field">
-              <span class="widget" tal:content="structure widget">
-                <input type="text" />
+             <td>
+              <span tal:content="cc/level">
+        	   LEVEL
               </span>
-              <tal:error tal:condition="widget/error">
-                <span tal:replace="structure widget/error">error</span>
-              </tal:error>
-              <tal:hint tal:condition="widget/hint">
-                <span class="hint" tal:content="structure widget/hint">hint</span>
-              </tal:hint>
+            </td>
+            <td tal:content="cc/course/semester">SEMESTER</td>
+            <td>
+              <a tal:attributes="href python: view.url(cc)"
+        	     tal:content="cc/__name__">
+            	REFERRER CODE
+              </a>
+            </td>
+            <td>
+              <a tal:attributes="href python:view.url(cc.course)"
+        	     tal:content="cc/course/code">
+            	COURSE CODE
+              </a>
+            </td>
+            <td>
+              <span tal:content="cc/course/title">
+        	   COURSE TITLE
+              </span>
+            </td>
+            <td>
+              <span tal:content="cc/core_or_elective">
+        	   MANDATORY
+              </span>
             </td>
           </tr>
-        </tal:block>
         </tbody>
-        </table>
-        <div class="actionButtons" tal:condition="view/availableActions">
-          <span tal:repeat="action view/actions"
-                tal:omit-tag="">
-            <input tal:condition="python:action.label in view.taboneactions"
-                   tal:replace="structure action/render"/>
-          </span>
-        </div>
-  </div>
-  <div id="tab-2">
-    <h3>Course Referrers</h3>
-    <table class="display dataTableManage">
-      <thead>
-        <tr>
-          <th>&nbsp;</th><th>Level</th><th>Semester</th><th>Referrer</th><th>Course</th><th>Title</th>
-          <th>Mandatory</th>
+      </table>
+      <div tal:condition="view/availableActions">
+        <span tal:repeat="action view/actions"
+              tal:omit-tag="">
+          <input tal:condition="python:action.label in view.tabtwoactions"
+                 tal:replace="structure action/render"/>
+        </span>
+      </div>
+    </div>
+    <div id="tab-3"> <br />
+      <table class="display dataTableManage">
+        <thead>
+          <tr>
+            <th>&nbsp;
+            </th>
+            <th>User Id
+            </th>
+            <th>Name
+            </th>
+            <th>Local Role
+            </th>
+          </tr>
+        </thead>
+        <tbody>
+          <tr tal:repeat="entry view/getUsersWithLocalRoles" class="gradeC"> <td>
+              <input type="checkbox" name="role_id" tal:attributes="value python: entry['user_name']+'|'+entry['local_role']" /> </td>
+            <td tal:content="entry/user_name"> USERNAME </td>
+            <td tal:content="entry/user_title"> USERTITLE </td>
+            <td tal:content="entry/local_role_title"> LOCAL ROLE </td>
+          </tr>
+        </tbody>
+      </table>
+      <div tal:condition="view/availableActions">
+        <span tal:repeat="action view/actions" tal:omit-tag="">
+          <input tal:condition="python:action.label in view.tabthreeactions1" tal:replace="structure action/render"/>
+        </span>
+      </div><br /><br />
+      <table class="form-table">
+        <tr> <td>
+            <select id="user" name="user">
+              <option tal:repeat="user view/getUsers" tal:attributes="value user/name">
+              <span tal:replace="user/val/title">USERTITLE
+              </span>
+              </option>
+            </select> </td> <td>
+            <select id="local_role" name="local_role">
+              <option tal:repeat="localrole view/getLocalRoles" tal:attributes="value localrole/name">
+              <span tal:replace="localrole/title">LOCALROLETITLE
+              </span>
+              </option>
+            </select> </td> <td>
+            <div tal:condition="view/availableActions">
+              <span tal:repeat="action view/actions" tal:omit-tag="">
+                <input tal:condition="python:action.label in view.tabthreeactions2" tal:replace="structure action/render"/>
+              </span>
+            </div> </td>
         </tr>
-      </thead>
-      <tbody>
-        <tr tal:repeat="cc context/values">
-           <td>
-            <input type="checkbox"
-      		 name="val_id"
-      		 tal:attributes="value cc/__name__" />
-          </td>
-           <td>
-            <span tal:content="cc/level">
-      	   LEVEL
-            </span>
-          </td>
-          <td tal:content="cc/course/semester">SEMESTER</td>
-          <td>
-            <a tal:attributes="href python: view.url(cc)"
-      	     tal:content="cc/__name__">
-          	REFERRER CODE
-            </a>
-          </td>
-          <td>
-            <a tal:attributes="href python:view.url(cc.course)"
-      	     tal:content="cc/course/code">
-          	COURSE CODE
-            </a>
-          </td>
-          <td>
-            <span tal:content="cc/course/title">
-      	   COURSE TITLE
-            </span>
-          </td>
-          <td>
-            <span tal:content="cc/core_or_elective">
-      	   MANDATORY
-            </span>
-          </td>
-        </tr>
-      </tbody>
-    </table>
-    <div class="actionButtons" tal:condition="view/availableActions">
-      <span tal:repeat="action view/actions"
-            tal:omit-tag="">
-        <input tal:condition="python:action.label in view.tabtwoactions"
-               tal:replace="structure action/render"/>
-      </span>
+      </table>
     </div>
   </div>
-  <div id="tab-3"> <br />
-    <table class="display dataTableManage">
-      <thead>
-        <tr>
-          <th>&nbsp;
-          </th>
-          <th>User Id
-          </th>
-          <th>Name
-          </th>
-          <th>Local Role
-          </th>
-        </tr>
-      </thead>
-      <tbody>
-        <tr tal:repeat="entry view/getUsersWithLocalRoles" class="gradeB"> <td>
-            <input type="checkbox" name="role_id" tal:attributes="value python: entry['user_name']+'|'+entry['local_role']" /> </td>
-          <td tal:content="entry/user_name"> USERNAME </td>
-          <td tal:content="entry/user_title"> USERTITLE </td>
-          <td tal:content="entry/local_role_title"> LOCAL ROLE </td>
-        </tr>
-      </tbody>
-    </table>
-    <div class="actionButtons" tal:condition="view/availableActions">
-      <span tal:repeat="action view/actions" tal:omit-tag="">
-        <input tal:condition="python:action.label in view.tabthreeactions1" tal:replace="structure action/render"/>
-      </span>
-    </div><br /><br />
-    <table class="zebra">
-      <tr> <td>
-          <select id="user" name="user">
-            <option tal:repeat="user view/getUsers" tal:attributes="value user/name">
-            <span tal:replace="user/val/title">USERTITLE
-            </span>
-            </option>
-          </select> </td> <td>
-          <select id="local_role" name="local_role">
-            <option tal:repeat="localrole view/getLocalRoles" tal:attributes="value localrole/name">
-            <span tal:replace="localrole/title">LOCALROLETITLE
-            </span>
-            </option>
-          </select> </td> <td>
-          <div tal:condition="view/availableActions">
-            <span tal:repeat="action view/actions" tal:omit-tag="">
-              <input tal:condition="python:action.label in view.tabthreeactions2" tal:replace="structure action/render"/>
-            </span>
-          </div> </td>
-      </tr>
-    </table>
-  </div>
-</div>
 </form>  
 
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/certificatepage.pt	(revision 7443)
@@ -1,5 +1,5 @@
 <h2 tal:content="context/longtitle">TITLE</h2>
 
-<table class="zebra">
+<table class="form-table">
 <thead>
 </thead>  
@@ -13,6 +13,6 @@
         </label>
       </td>
-      <td class="field" tal:on-error="default">
-        <div class="widget" tal:content="structure widget">
+      <td tal:on-error="default">
+        <div tal:content="structure widget">
           <input type="text" />
         </div>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/configurationmanagepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/configurationmanagepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/configurationmanagepage.pt	(revision 7443)
@@ -1,11 +1,10 @@
 <h2 i18n:translate="" tal:condition="view/label" tal:content="view/label">Label</h2>
-<div class="form-status"  tal:define="status view/status"  tal:condition="status"> Form Status:
+<div class="alert-message error"  tal:define="status view/status"  tal:condition="status"> Form Status:
   <span i18n:translate="" tal:content="view/status"> Form status summary
   </span>
 </div>
-<form action="." tal:attributes="action request/URL" method="POST" class="edit-form" enctype="multipart/form-data">
-  <div id="tabs">
-    <ul>
-      <li>
+<form action="." tal:attributes="action request/URL" method="POST" enctype="multipart/form-data">
+    <ul class="tabs" data-tabs="tabs">
+      <li class="active">
       <a href="#tab-1">
         <span>Site Settings
@@ -16,18 +15,19 @@
       </li>
     </ul>
-    <div id="tab-1">
-      <table class="zebra">
+    <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
         <tbody>
           <tal:block repeat="widget view/widgets">
             <tr>
-              <td class="label">
+              <td>
                 <label tal:attributes="for widget/name">
-                  <span class="required" tal:condition="widget/required">*
+                  <span tal:condition="widget/required">*
                   </span>
                   <span i18n:translate="" tal:content="widget/label">label
                   </span>:
                 </label> </td>
-              <td class="field">
-                <span class="widget" tal:content="structure widget">
+              <td>
+                <span tal:content="structure widget">
                   <input type="text" />
                 </span>
@@ -37,5 +37,5 @@
                 </tal:error>
                 <tal:hint tal:condition="widget/hint">
-                  <span class="hint" tal:content="structure widget/hint">hint
+                  <span tal:content="structure widget/hint">hint
                   </span>
                 </tal:hint> </td>
@@ -44,5 +44,5 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
           <input tal:condition="python:action.label in view.taboneactions" tal:replace="structure action/render"/>
@@ -61,5 +61,5 @@
         </thead>
         <tbody>
-          <tr tal:repeat="entry view/getSessionConfigurations" class="gradeB"> <td>
+          <tr tal:repeat="entry view/getSessionConfigurations" class="gradeC"> <td>
               <input type="checkbox" name="val_id" tal:attributes="value entry/name" /> </td> <td>
               <a href="" tal:attributes="href entry/url" tal:content="entry/title">Name</a> </td>
@@ -67,5 +67,5 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
           <input tal:condition="python:action.label in view.tabtwoactions" tal:replace="structure action/render"/>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/contactform.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/contactform.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/contactform.pt	(revision 7443)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
   <h2 i18n:translate=""
@@ -6,5 +6,5 @@
     tal:content="view/label">Label</h2>
 
-  <div class="form-status"
+  <div class="alert-message error"
       tal:define="status view/status"
       tal:condition="status">
@@ -21,5 +21,5 @@
          tal:content="widget/label">Label
     </div>
-    <div class="widget" tal:content="structure widget">
+    <div tal:content="structure widget">
       Textbody
     </div>
@@ -27,5 +27,5 @@
   </tal:block>
 
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <input tal:repeat="action view/actions"
            tal:replace="structure action/render"
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/coursepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/coursepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/coursepage.pt	(revision 7443)
@@ -1,25 +1,25 @@
 <h2 tal:content="context/title">TITLE</h2>
 
-<table class="listing">
+<table class="form-table">
   <thead>
   </thead>
   <tbody>
-    <tr class="odd">
+    <tr>
       <td>Code:</td>
       <td tal:content="context/__name__">CODE</td>
     </tr>  
-    <tr class="even">
+    <tr>
       <td>Title:</td>
       <td tal:content="context/title">THE TITLE</td>
     </tr>
-    <tr class="odd">
+    <tr>
       <td>Credits:</td>
       <td tal:content="context/credits">CREDITS</td>
     </tr>
-    <tr class="even">
+    <tr>
       <td>Passmark:</td>
       <td tal:content="context/passmark">PASSMARK</td>
     </tr>
-    <tr class="odd">
+    <tr>
       <td>Semester/Term:</td>
       <td tal:content="context/semester">SEMESTER</td>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport1page.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport1page.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport1page.pt	(revision 7443)
@@ -19,5 +19,5 @@
       tal:attributes="class python: repeat['file'].odd() and 'odd' or ''">
         <td>
-          <button type="submit" name="select"
+          <button type="submit" name="select" class="btn"
             tal:attributes="value file/name">Select</button>
         </td>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport2page.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport2page.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport2page.pt	(revision 7443)
@@ -13,5 +13,5 @@
   </p>
   <div>
-    <table class = "zebra"
+    <table
            tal:define="body view/getPreviewBody;
                         headers view/getPreviewHeader;
@@ -19,6 +19,5 @@
       <thead>
         <tr>
-          <th style="border: 1px solid #888;"
-              tal:repeat="headerfield headers"
+          <th tal:repeat="headerfield headers"
               tal:content="headerfield"> headerfield
           </th>
@@ -28,6 +27,5 @@
         <tr tal:repeat="row body">
           <td tal:repeat="value row"
-              tal:content="value"
-              style="border: 1px solid #000;"> value
+              tal:content="value"> value
           </td>
         </tr>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport3page.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport3page.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterimport3page.pt	(revision 7443)
@@ -1,2 +1,6 @@
+<div class="alert-message success" tal:condition="not: view/getWarnings">
+  Header fields OK
+</div>
+
 <h2 i18n:translate=""
 tal:condition="view/label"
@@ -25,10 +29,7 @@
      tal:attributes="value view/mode" />
   </p>
-  <div class="alert notice ui-state-info" tal:condition="not: view/getWarnings">
-    <span class="ui-icon ui-icon-info">A</span>
-    Header fields OK
-  </div>
+
   <div>
-    <table class = "zebra"
+    <table class="condensed-table"
      tal:define="body view/getPreviewBody;
            headers view/headerfields;
@@ -36,6 +37,5 @@
       <thead>
         <tr>
-          <th style="border: 1px solid #888;"
-              tal:repeat="headerfield headers"
+          <th tal:repeat="headerfield headers"
               tal:content="headerfield">
             headerfield
@@ -43,12 +43,10 @@
         </tr>
         <tr>
-          <th style="border: 1px solid #888; text-align=center;"
-              tal:repeat="headerfield headers">
+          <th tal:repeat="headerfield headers">
             <i>change to:</i>
           </th>
         </tr>
         <tr>
-          <th style="border: 1px solid #888;"
-              tal:repeat="headerfield headers">
+          <th tal:repeat="headerfield headers">
             <select name="headerfield">
               <option tal:repeat="opt view/getPossibleHeaders"
@@ -65,6 +63,5 @@
         <tr tal:repeat="row body">
           <td tal:repeat="value row"
-              tal:content="value"
-              style="border: 1px solid #000;">
+              tal:content="value">
             value
           </td>
@@ -77,5 +74,5 @@
   <input type="reset" name="reset" value="Reset" />
   <input type="submit" name="update" value="Set headerfields" />
-  <br />
+  <br /><br />
   <input type="submit" name="back2" value="Back to step 2" />
   <input tal:attributes="disabled python: view.getWarnings() and 'disabled' or ''"
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterlogspage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterlogspage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterlogspage.pt	(revision 7443)
@@ -1,36 +1,34 @@
-<h2 i18n:translate=""
-tal:condition="view/label"
-tal:content="view/label">Label</h2>
-
+<h2 i18n:translate="" tal:condition="view/label" tal:content="view/label">Label</h2>
 <div tal:define="files view/files">
-  <p tal:condition="not: files">
-    Currently no log files are available.
+  <p tal:condition="not: files">Currently no log files are available.
   </p>
-  <table tal:condition="files">
+  <table tal:condition="files" class="condensed-table">
     <thead>
       <tr>
-  <th></th><th>File</th><th>Date</th><th>Size</th>
+        <th>
+        </th>
+        <th>File
+        </th>
+        <th>Date
+        </th>
+        <th>Size
+        </th>
       </tr>
     </thead>
     <tbody>
-      <tr tal:repeat="file files"
-    tal:attributes="class python: repeat['file'].odd() and 'odd' or 'even'">
-  <td class="text-center">
-    <form method="POST">
-      <input type="submit" name="show" value="Show" />
-      <input type="hidden" name="logname"
-       tal:attributes="value file/name" />
-    </form>
-  </td>
-  <td tal:content="file/name">file.name</td>
-  <td tal:content="file/uploaddate">Fri Jan 15 17:44:25 2010</td>
-  <td tal:content="file/getSize">12 bytes</td>
+      <tr tal:repeat="file files" tal:attributes="class python: repeat['file'].odd() and 'odd' or 'even'">
+        <td class="text-center">
+          <form method="POST">
+            <input type="submit" class="btn" name="show" value="Show" />
+            <input type="hidden" name="logname" tal:attributes="value file/name" />
+          </form></td>
+        <td tal:content="file/name">file.name</td>
+        <td tal:content="file/uploaddate">Fri Jan 15 17:44:25 2010</td>
+        <td tal:content="file/getSize">12 bytes</td>
       </tr>
     </tbody>
   </table>
-
   <form method="POST">
     <input type="submit" name="back" value="Back to Data Center" />
   </form>
-
 </div>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterlogsshowfilepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterlogsshowfilepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterlogsshowfilepage.pt	(revision 7443)
@@ -7,5 +7,5 @@
 </form>
 
-<div class="bd">
+<div>
   <pre tal:content="view/filecontents">
     blah, blah
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacentermanagepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacentermanagepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacentermanagepage.pt	(revision 7443)
@@ -5,17 +5,14 @@
 <form method="POST">
   <div>
-    <label for="newpath">Storage path:</label>
+    Storage path:
     <input type="text" name="newpath"
      tal:attributes="value context/storage" />
     <br /><br />
-    <div>
-      <input type="checkbox" name="move" checked="checked" />
-      <label for="move">Copy existing data to new storage?</label>
-    </div>
-    <div>
-      <input type="checkbox" name="overwrite" checked="no" />
-      <label for="overwrite">Overwrite contents in new location?</label>
-    </div>
-    <br />
+    Copy existing data to new storage? &nbsp;&nbsp;
+    <input type="checkbox" name="move" checked="checked" />
+    <br /><br />
+    Overwrite contents in new location? &nbsp;&nbsp;
+    <input type="checkbox" name="overwrite" checked="no" />
+    <br /><br />
     <input type="submit" name="save" value="Save" />
     <input type="reset" name="reset" value="Reset" />
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterpage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterpage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/datacenterpage.pt	(revision 7443)
@@ -19,6 +19,5 @@
   </thead>
   <tbody>
-    <tr tal:repeat="file context/getFiles"
-	tal:attributes="class python: repeat['file'].odd() and 'odd' or 'even'">
+    <tr tal:repeat="file context/getFiles">
       <td tal:content="file/name">thefilename</td>
       <td tal:content="file/size">12 k</td>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/default_waeup_display_form.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/default_waeup_display_form.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/default_waeup_display_form.pt	(revision 7443)
@@ -3,9 +3,9 @@
     tal:content="view/label">Label</h2>
 
-<table class="zebra">
+<table class="form-table">
   <tbody>
     <tal:block repeat="widget view/widgets">
       <tr>
-        <td class="fieldname" width="33%">
+        <td width="33%">
           <tal:block content="widget/label"/>:
         </td>
@@ -18,5 +18,5 @@
   </tbody>
   <tfoot>
-    <tr class="controls">
+    <tr>
       <td colspan="2" class="align-right">
         <input tal:repeat="action view/actions"
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/default_waeup_edit_form.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/default_waeup_edit_form.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/default_waeup_edit_form.pt	(revision 7443)
@@ -6,5 +6,5 @@
     tal:content="view/label">Label</h2>
 
-  <div class="form-status"
+  <div class="alert-message error"
       tal:define="status view/status"
       tal:condition="status">
@@ -20,5 +20,5 @@
   </div>
 
-  <table>
+  <table class="form-table">
     <tbody>
       <tal:block repeat="widget view/widgets">
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/departmentmanagepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/departmentmanagepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/departmentmanagepage.pt	(revision 7443)
@@ -1,39 +1,39 @@
 <h2 i18n:translate="" tal:condition="view/label" tal:content="view/label">Label</h2>
-<div class="form-status"  tal:define="status view/status"  tal:condition="status"> Form Status:
+<div class="alert-message error"  tal:define="status view/status"  tal:condition="status"> Form Status:
   <span i18n:translate="" tal:content="view/status"> Form status summary
   </span>
 </div>
-<form action="." tal:attributes="action request/URL" method="POST" class="edit-form" enctype="multipart/form-data">
-  <div id="tabs">
-    <ul>
-      <li>
-      <a href="#tab-1">
-        <span>Settings
-        </span></a>
-      </li>
-      <li>
-      <a href="#tab-2">Courses</a>
-      </li>
-      <li>
-      <a href="#tab-3">Certificates</a>
-      </li>
-      <li>
-      <a href="#tab-4">Local Roles</a>
-      </li>
-    </ul>
-    <div id="tab-1">
-      <table class="zebra">
+<form action="." tal:attributes="action request/URL" method="POST" enctype="multipart/form-data">
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active">
+    <a href="#tab-1">
+      <span>Settings
+      </span></a>
+    </li>
+    <li>
+    <a href="#tab-2">Courses</a>
+    </li>
+    <li>
+    <a href="#tab-3">Certificates</a>
+    </li>
+    <li>
+    <a href="#tab-4">Local Roles</a>
+    </li>
+  </ul>
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
         <tbody>
           <tal:block repeat="widget view/widgets">
             <tr>
-              <td class="label">
+              <td>
                 <label tal:attributes="for widget/name">
-                  <span class="required" tal:condition="widget/required">*
+                  <span tal:condition="widget/required">*
                   </span>
                   <span i18n:translate="" tal:content="widget/label">label
                   </span>:
                 </label> </td>
-              <td class="field">
-                <span class="widget" tal:content="structure widget">
+              <td>
+                <span tal:content="structure widget">
                   <input type="text" />
                 </span>
@@ -43,5 +43,5 @@
                 </tal:error>
                 <tal:hint tal:condition="widget/hint">
-                  <span class="hint" tal:content="structure widget/hint">hint
+                  <span tal:content="structure widget/hint">hint
                   </span>
                 </tal:hint> </td>
@@ -50,5 +50,5 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
           <input tal:condition="python:action.label in view.taboneactions" tal:replace="structure action/render"/>
@@ -69,5 +69,5 @@
         </thead>
         <tbody>
-          <tr tal:repeat="entry view/getCourses" class="gradeB"> <td>
+          <tr tal:repeat="entry view/getCourses" class="gradeC"> <td>
               <input type="checkbox" name="val_id" tal:attributes="value entry/name" /> </td> <td>
               <a href="" tal:attributes="href entry/url" tal:content="entry/name">Name</a> </td>
@@ -76,5 +76,5 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
           <input tal:condition="python:action.label in view.tabtwoactions" tal:replace="structure action/render"/>
@@ -95,5 +95,5 @@
         </thead>
         <tbody>
-          <tr tal:repeat="entry view/getCertificates" class="gradeB"> <td>
+          <tr tal:repeat="entry view/getCertificates" class="gradeC"> <td>
               <input type="checkbox" name="val_id" tal:attributes="value entry/name" /> </td> <td>
               <a href="" tal:attributes="href entry/url" tal:content="entry/name">Name</a> </td>
@@ -102,5 +102,5 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
           <input tal:condition="python:action.label in view.tabthreeactions" tal:replace="structure action/render"/>
@@ -123,5 +123,5 @@
         </thead>
         <tbody>
-          <tr tal:repeat="entry view/getUsersWithLocalRoles" class="gradeB"> <td>
+          <tr tal:repeat="entry view/getUsersWithLocalRoles" class="gradeC"> <td>
               <input type="checkbox" name="role_id" tal:attributes="value python: entry['user_name']+'|'+entry['local_role']" /> </td>
             <td tal:content="entry/user_name"> USERNAME </td>
@@ -131,10 +131,10 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
           <input tal:condition="python:action.label in view.tabfouractions1" tal:replace="structure action/render"/>
         </span>
       </div> <br /><br />
-      <table class="zebra">
+      <table class="form-table">
         <tr> <td>
             <select id="user" name="user">
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/departmentpage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/departmentpage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/departmentpage.pt	(revision 7443)
@@ -3,11 +3,10 @@
 tal:content="view/label">Label</h2>
 
-<div id="tabs">
-    <ul>
-      <li><a href="#tab-1"><span>Courses</span></a></li>
-      <li><a href="#tab-2"><span>Certificates</span></a></li>
-    </ul>
-    
-    <div id="tab-1"> 
+<ul class="tabs" data-tabs="tabs">
+  <li class="active"><a href="#tab-1"><span>Courses</span></a></li>
+  <li><a href="#tab-2"><span>Certificates</span></a></li>
+</ul>
+<div class="tab-content">
+    <div id="tab-1" class="active">
     <br /> 
     <table class="display dataTable">
@@ -18,6 +17,5 @@
       </thead>
       <tbody>
-        <tr tal:repeat="entry view/getCourses"
-    	class="gradeB">
+        <tr tal:repeat="entry view/getCourses" class="gradeC">
           <td>
         	<a href=""
@@ -42,6 +40,5 @@
       </thead>
       <tbody>
-        <tr tal:repeat="entry view/getCertificates"
-    	class="gradeB">
+        <tr tal:repeat="entry view/getCertificates" class="gradeC">
           <td>
         	<a href=""
@@ -55,5 +52,4 @@
       </tbody>
     </table>
-    <br /><br />
     </div>
 </div>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultiescontainermanagepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultiescontainermanagepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultiescontainermanagepage.pt	(revision 7443)
@@ -3,5 +3,5 @@
     tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,51 +13,39 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
-  <div id="tabs">
-    <ul>
-      <li><a href="#tab-1">
-        <span tal:content="view/subunits">Contents</span>
-      </a></li>
-    </ul>
-
-    <div id="tab-1">
-      <h3 tal:content="view/subunits">Faculties</h3>
-      <table class="zebra">
-        <thead>
-          <tr>
-            <th>&nbsp;</th><th>Code</th><th>Title</th>
-          </tr>
-        </thead>
-        <tbody>
-          <tr tal:repeat="dep context/values">
-            <td>
-              <input type="checkbox"
-                     name="val_id"
-                     tal:attributes="value dep/code" />
-            </td>
-            <td>
-              <a tal:attributes="href python: view.url(dep)"
-                 tal:content="dep/__name__">
-                ID
-              </a>
-            </td>
-            <td>
-              <span tal:content="dep/title">
-                ID
-              </span>
-            </td>
-          </tr>
-        </tbody>
-      </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
-        <span tal:repeat="action view/actions"
-              tal:omit-tag="">
-          <input tal:condition="python:action.label in view.taboneactions"
-                 tal:replace="structure action/render"/>
-        </span>
-      </div>
-
-    </div>
+  <table>
+    <thead>
+      <tr>
+        <th>&nbsp;</th><th>Code</th><th>Title</th>
+      </tr>
+    </thead>
+    <tbody>
+      <tr tal:repeat="dep context/values">
+        <td>
+          <input type="checkbox"
+                 name="val_id"
+                 tal:attributes="value dep/code" />
+        </td>
+        <td>
+          <a tal:attributes="href python: view.url(dep)"
+             tal:content="dep/__name__">
+            ID
+          </a>
+        </td>
+        <td>
+          <span tal:content="dep/title">
+            ID
+          </span>
+        </td>
+      </tr>
+    </tbody>
+  </table>
+  <div tal:condition="view/availableActions">
+    <span tal:repeat="action view/actions"
+          tal:omit-tag="">
+      <input tal:condition="python:action.label in view.taboneactions"
+             tal:replace="structure action/render"/>
+    </span>
   </div>
 </form>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultymanagepage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultymanagepage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultymanagepage.pt	(revision 7443)
@@ -1,40 +1,41 @@
 <h2 i18n:translate="" tal:condition="view/label" tal:content="view/label">Label</h2>
-<div class="form-status" tal:define="status view/status" tal:condition="status"> Form Status:
+<div class="alert-message error" tal:define="status view/status"
+     tal:condition="status"> Form Status:
   <span i18n:translate="" tal:content="view/status"> Form status summary
   </span>
 </div>
-<form action="." tal:attributes="action request/URL" method="POST" class="edit-form" enctype="multipart/form-data">
-  <div id="tabs">
-    <ul>
-      <li>
-      <a href="#tab-1">
-        <span>Settings
-        </span></a>
-      </li>
-      <li>
-      <a href="#tab-2">
-        <span tal:content="view/subunits">Contents
-        </span> </a>
-      </li>
-      <li>
-      <a href="#tab-3">
-        <span>Local Roles
-        </span></a>
-      </li>
-    </ul>
-    <div id="tab-1">
-      <table class="zebra">
+<form action="." tal:attributes="action request/URL" method="POST" enctype="multipart/form-data">
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active">
+    <a href="#tab-1">
+      <span>Settings
+      </span></a>
+    </li>
+    <li>
+    <a href="#tab-2">
+      <span tal:content="view/subunits">Contents
+      </span> </a>
+    </li>
+    <li>
+    <a href="#tab-3">
+      <span>Local Roles
+      </span></a>
+    </li>
+  </ul>
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
         <tbody>
           <tal:block repeat="widget view/widgets">
             <tr>
-              <td class="label">
+              <td>
                 <label tal:attributes="for widget/name">
-                  <span class="required" tal:condition="widget/required">*
+                  <span tal:condition="widget/required">*
                   </span>
                   <span i18n:translate="" tal:content="widget/label">label
                   </span>:
                 </label> </td>
-              <td class="field">
-                <span class="widget" tal:content="structure widget">
+              <td>
+                <span tal:content="structure widget">
                   <input type="text" />
                 </span>
@@ -44,5 +45,5 @@
                 </tal:error>
                 <tal:hint tal:condition="widget/hint">
-                  <span class="hint" tal:content="structure widget/hint">hint
+                  <span tal:content="structure widget/hint">hint
                   </span>
                 </tal:hint> </td>
@@ -51,7 +52,8 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
-          <input tal:condition="python:action.label in view.taboneactions" tal:replace="structure action/render"/>
+          <input tal:condition="python:action.label in view.taboneactions"
+                 tal:replace="structure action/render"/>
         </span>
       </div>
@@ -59,5 +61,5 @@
     <div id="tab-2">
       <h3 tal:content="view/subunits">Departments</h3>
-      <table class="zebra">
+      <table>
         <thead>
           <tr>
@@ -72,6 +74,8 @@
         <tbody>
           <tr tal:repeat="dep context/values"> <td>
-              <input type="checkbox" name="val_id" tal:attributes="value dep/code" /> </td> <td>
-              <a tal:attributes="href python: view.url(dep)" tal:content="dep/__name__"> ID</a> </td> <td>
+              <input type="checkbox" name="val_id"
+                     tal:attributes="value dep/code" /> </td> <td>
+              <a tal:attributes="href python: view.url(dep)"
+                 tal:content="dep/__name__"> ID</a> </td> <td>
               <span tal:content="dep/title">ID
               </span> </td>
@@ -79,7 +83,8 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
-          <input tal:condition="python:action.label in view.tabtwoactions" tal:replace="structure action/render"/>
+          <input tal:condition="python:action.label in view.tabtwoactions"
+                 tal:replace="structure action/render"/>
         </span>
       </div>
@@ -100,6 +105,7 @@
         </thead>
         <tbody>
-          <tr tal:repeat="entry view/getUsersWithLocalRoles" class="gradeB"> <td>
-              <input type="checkbox" name="role_id" tal:attributes="value python: entry['user_name']+'|'+entry['local_role']" /> </td>
+          <tr tal:repeat="entry view/getUsersWithLocalRoles" class="gradeC"> <td>
+              <input type="checkbox" name="role_id"
+              tal:attributes="value python: entry['user_name']+'|'+entry['local_role']" /> </td>
             <td tal:content="entry/user_name"> USERNAME </td>
             <td tal:content="entry/user_title"> USERTITLE </td>
@@ -108,10 +114,11 @@
         </tbody>
       </table>
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <span tal:repeat="action view/actions" tal:omit-tag="">
-          <input tal:condition="python:action.label in view.tabthreeactions1" tal:replace="structure action/render"/>
+          <input tal:condition="python:action.label in view.tabthreeactions1"
+                 tal:replace="structure action/render"/>
         </span>
       </div><br /><br />
-      <table class="zebra">
+      <table class="form-table">
         <tr> <td>
             <select id="user" name="user">
@@ -122,5 +129,6 @@
             </select> </td> <td>
             <select id="local_role" name="local_role">
-              <option tal:repeat="localrole view/getLocalRoles" tal:attributes="value localrole/name">
+              <option tal:repeat="localrole view/getLocalRoles"
+                      tal:attributes="value localrole/name">
               <span tal:replace="localrole/title">LOCALROLETITLE
               </span>
@@ -129,5 +137,6 @@
             <div tal:condition="view/availableActions">
               <span tal:repeat="action view/actions" tal:omit-tag="">
-                <input tal:condition="python:action.label in view.tabthreeactions2" tal:replace="structure action/render"/>
+                <input tal:condition="python:action.label in view.tabthreeactions2"
+                       tal:replace="structure action/render"/>
               </span>
             </div> </td>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultypage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultypage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/facultypage.pt	(revision 7443)
@@ -5,5 +5,5 @@
 </div>
 
-<table class="zebra">
+<table>
   <thead>
     <tr>
@@ -14,5 +14,6 @@
   <tbody>
     <tr tal:repeat="value context/values">
-      <td> <a tal:attributes="href value/__name__"> <span tal:content="value/code">Name</span></a></td>
+      <td> <a tal:attributes="href value/__name__">
+          <span tal:content="value/code">Name</span></a></td>
       <td tal:content="value/longtitle">Title</td>
     </tr>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/loginpage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/loginpage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/loginpage.pt	(revision 7443)
@@ -1,18 +1,19 @@
 <h2 i18n:translate=""  tal:condition="view/label"  tal:content="view/label">Label</h2>
 <form method="post">
-  <table id="login" class="form"   summary="Table for entering login information">
+  <table id="login" class="form-table" summary="Table for entering login information">
     <tbody>
       <tr>
-        <th>
-          <label for="form.login">User Name or Student Id
-          </label>
-        </th> <td>
-          <input type="text" id="login" name="form.login" size="20" /> </td>
+        <td>
+          <label>User Name or Student Id:</label>
+        </td>
+        <td>
+          <input type="text" id="login" name="form.login" size="20" />
+        </td>
       </tr>
       <tr>
-        <th>
-          <label for="form.password">Password
-          </label>
-        </th><td>
+        <td>
+          <label>Password:</label>
+        </td>
+        <td>
           <input type="password" id="password" name="form.password"  size="20" value="" />
           &nbsp;&nbsp;
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/notfound.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/notfound.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/notfound.pt	(revision 7443)
@@ -3,5 +3,5 @@
 </h2>
 
-<div class="error"><b>Please note the following:</b></div>
+<div><b>Please note the following:</b></div>
 <div>
   <ol class="list">
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/plainactionbutton.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/plainactionbutton.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/plainactionbutton.pt	(revision 7443)
@@ -1,4 +1,4 @@
-<span class="yui-button" tal:condition="viewlet/target_url">
-  <span class="first-child">
+<span tal:condition="viewlet/target_url">
+  <span>
     <a href=""
        tal:attributes="href viewlet/target_url">
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/searchpage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/searchpage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/searchpage.pt	(revision 7443)
@@ -31,5 +31,3 @@
         </tbody>
     </table>
-    <div class="actionButtons">
-    </div>
 </span>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/staffsitelayout.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/staffsitelayout.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/staffsitelayout.pt	(revision 7443)
@@ -13,14 +13,4 @@
         tal:attributes="title string:RSS feed of ${layout/getAppTitle};
             href python: view.url(layout.site, 'feed.rss')" />
-
-
-    <style type="text/css">
-      body {
-        padding-top: 60px;
-      }
-    </style>
-
-
-
   </head>
   <body>
@@ -76,5 +66,5 @@
       <div class="content">
         <div class="row">
-          <div class="span14"
+          <div class="span12"
               tal:define="message context/@@messages"
               tal:condition="python: len(message)>11">
@@ -82,9 +72,9 @@
             </div>
           </div>
-          <div class="span14">
-            <tal:actionbar content="structure provider:actionbar" />
+          <div class="span12" tal:condition="provider:actionbar">
+            <span tal:replace="structure provider:actionbar" />
+            <br /><br />
           </div>
-          <div class="span14">&nbsp;</div>
-          <div class="span14" tal:content="structure view/content"> THE CONTENT
+          <div class="span12" tal:content="structure view/content"> THE CONTENT
           </div>
         </div>
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/subobjectlist.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/subobjectlist.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/subobjectlist.pt	(revision 7443)
@@ -8,6 +8,5 @@
   </thead>
   <tbody>
-    <tr tal:repeat="row viewletmanager/rows"
-	tal:attributes="class python: repeat['row'].odd() and 'odd' or 'even'">
+    <tr tal:repeat="row viewletmanager/rows">
       <td tal:repeat="viewlet row">
 	<div tal:replace="structure viewlet/render">
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/usereditformpage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/usereditformpage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/usereditformpage.pt	(revision 7443)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
   <h2 i18n:translate=""
@@ -6,5 +6,5 @@
     tal:content="view/label">Label</h2>
 
-  <div class="form-status"
+  <div class="alert-message error"
       tal:define="status view/status"
       tal:condition="status">
@@ -20,16 +20,16 @@
   </div>
 
-  <table class="zebra">
+  <table class="form-table">
     <tbody>
       <tal:block repeat="widget view/widgets">
         <tr>
-          <td class="label">
+          <td>
             <label tal:attributes="for widget/name">
-              <span class="required" tal:condition="widget/required">*</span>
+              <span tal:condition="widget/required">*</span>
               <span i18n:translate="" tal:content="widget/label">label</span>:
             </label>
           </td>
-          <td class="field">
-            <span class="widget" tal:content="structure widget">
+          <td>
+            <span tal:content="structure widget">
               <input type="text" />
             </span>
@@ -38,5 +38,5 @@
             </tal:error>
             <tal:hint tal:condition="widget/hint">
-              <span class="hint" tal:content="structure widget/hint">hint</span>
+              <span tal:content="structure widget/hint">hint</span>
             </tal:hint>
           </td>
@@ -44,5 +44,5 @@
       </tal:block>
       <tr>
-        <td class="label"><label>Password:</label></td>
+        <td><label>Password:</label></td>
         <td>
           <input name="password" type="password"  />
@@ -50,5 +50,5 @@
       </tr>
       <tr>
-        <td class="label"><label>Retype password:</label></td>
+        <td><label>Retype password:</label></td>
         <td>
           <input name="control_password" type="password" />
@@ -58,5 +58,5 @@
     </tbody>
   </table>
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <input tal:repeat="action view/actions"
            tal:replace="structure action/render"
Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/userscontainerpage.pt
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/userscontainerpage.pt	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/templates/userscontainerpage.pt	(revision 7443)
@@ -1,14 +1,9 @@
 <h2>Portal Users</h2>
 
-<p>
-  Here you can manage portal users.  
-</p>
-
-<table class="zebra">
+<table>
   <thead>
     <tr>
       <th>User ID</th>
       <th>Name</th>
-      <th>Description</th>
       <th>Portal Roles</th>
       <th>Local Roles</th>
@@ -20,5 +15,4 @@
       <td tal:content="account/name">User name</td>
       <td tal:content="account/title">Title</td>
-      <td tal:content="account/description">Description</td>
       <td tal:content="structure python:view.getSiteRoles(account)">SITE ROLES</td>
       <td tal:content="structure python:view.getLocalRoles(account)">LOCAL ROLES</td>

Index: /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/resources.py
===================================================================
--- /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/resources.py	(revision 7442)
+++ /main/waeup.sirp/branches/henrik-bootstrap/src/waeup/sirp/browser/resources.py	(revision 7443)
@@ -140,8 +140,8 @@
 toggleall = ResourceInclusion(waeup_sirp, 'toggleall.js')
 
 #: A resource that binds jQueryUI tabs to <div> tags with class
 #: ``tabs``.
 #:
 #: If you want jQuery tabs for some <div>s in your page then you
 #: have to perform two steps:
 #:
@@ -159,31 +159,30 @@
 #:   into the HTML page generated.
 #:
-#: * In your HTML code add some ``<div>`` tag with ``class`` set to
-#:   ``tabs``, like this:
+#: * In your HTML code add some tags with like this:
 #:
 #:    .. code-block:: html
-#:
-#:      <div id="tabs">
-#:        <ul>
-#:          <li><a href="#tab-1"><span>Tab 1 Heading</span></a></li>
-#:          <li><a href="#tab-2"><span>Tab 2 Heading</span></a></li>
-#:        </ul>
-#:        <div id="tab-1">
-#:          Content of tab 1
-#:        </div>
-#:        <div id="tab-2">
-#:          Content of tab 2
-#:        </div>
-#:      </div>
+
+#:     <ul class="tabs" data-tabs="tabs" >
+#:       <li class="active"><a href="#tab-1">Tab 1 Heading</a></li>
+#:       <li><a href="#tab-2">Tab 2 Heading</a></li>
+#:       <li><a href="#tab-3">Tab 3 Heading</a></li>
+#:     </ul>
+
+#:     <div class="tab-content">
+#:       <div id="tab-1" class="active">...</div>
+#:       <div id="tab-2">...</div>
+#:       <div id="tab-3">...</div>
+#:     </div>
 #:
 #: When the HTML is rendered, clicking into one of the tabs will make
 #: other <div>s disappear. See
 #:
-#:   http://jqueryui.com/demos/tabs/
+#:   http://twitter.github.com/bootstrap/javascript.html#tabs
 #:
 #: for details.
 #:
-tabs = ResourceInclusion(waeup_sirp, 'tabs.js',
-                         depends=[jquery, jqueryui])
+tabs = ResourceInclusion(waeup_sirp, 'bootstrap-tabs.js',
+                          depends=[jquery])
+
 
 #: Resource that makes datatables for jQuery UI available.
@@ -140,8 +140,8 @@
 toggleall = ResourceInclusion(waeup_sirp, 'toggleall.js')
 
-#: A resource that binds jQueryUI tabs to <div> tags with class
+#: A resource that binds Bootstrap tabs to <div> tags with class
 #: ``tabs``.
 #:
@@ -140,8 +140,8 @@
 #: ``tabs``.
 #:
-#: If you want jQuery tabs for some <div>s in your page then you
+#: If you want Bootstrap tabs in your page then you
 #: have to perform two steps:
 #: